import requests
from requests.adapters import HTTPAdapter
from requests.packages.urllib3.util.retry import Retry
import json

def s3upload(endpoint:str, api_key:str, payload:str):
    hdr = {'Content-Type':'application/json','x-api-key':api_key}
    sess = requests.Session()
    retries = Retry(total=5, backoff_factor=.1)
    sess.mount('https://', HTTPAdapter(max_retries=retries))

    try:
        resp = sess.post(endpoint, headers=hdr, timeout=30)

        resp.raise_for_status()
    except requests.exceptions.HTTPError as http_err:
        print(f'HTTP error occurred: {http_err}')  # Python 3.6
        return http_err
    except Exception as err:
        print(f'Other error occurred: {err}')  # Python 3.6
        return err
    else:
        print('Successful response for cloud urls.')
        response = json.loads(resp.json()['body'])
        files = {'file': (response['fields']['key'], payload)}

    try:
        http_response = sess.post(response['url_upload'], data=response['fields'],files=files, timeout=30)
        http_response.raise_for_status()
    except requests.exceptions.HTTPError as http_err:
        print(f'HTTP error occurred: {http_err}')  # Python 3.6
        return http_err
    except Exception as err:
        print(f'Other error occurred: {err}')  # Python 3.6
        return err
    else:
        print('Successful response payload dispatch.')
        return {'response_urls':resp.json(),'response_upload_status_code':http_response.status_code}



from distutils.core import setup
setup(
  name = 'BTLibrary',
  packages = ['BTLibrary'],   
  version = '0.4',      
  license='MIT',       
  description = 'This package is used to provide various utilities for project support.',   
  author = 'David Sinex',                   
  author_email = 'dave.sinex@btgeophysics.com',    
  url = 'http://www.btgeophysics.com',  
  download_url = 'https://github.com/humberto77/BTUtilities/archive/R0_3.tar.gz',    
  keywords = ['Utilities', 'BTG'],   
  install_requires=[           
          'jsonpickle',
          'requests',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   
    'Programming Language :: Python :: 3',     
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
  ],
)


import zlib

import json, base64
import jsonpickle
ZIPJSON_KEY = 'base64(zip(o))'

def json_zip(j):

    j = {
        ZIPJSON_KEY: base64.b64encode(
            zlib.compress(
                jsonpickle.encode(j).encode('utf-8')
            )
        ).decode('ascii')
    }

    return j


def json_unzip(j, insist=True):
    try:
        assert (j[ZIPJSON_KEY])
        assert (set(j.keys()) == {ZIPJSON_KEY})
    except:
        if insist:
            raise RuntimeError("JSON not in the expected format {" + str(ZIPJSON_KEY) + ": zipstring}")
        else:
            return j

    try:
        j = zlib.decompress(base64.b64decode(j[ZIPJSON_KEY]))
    except:
        raise RuntimeError("Could not decode/unzip the contents")

    try:
        j = jsonpickle.decode(j)
    except:
        raise RuntimeError("Could interpret the unzipped contents")

    return j

    
if __name__=="__main__":
    json2 = {'atest':4}
    

    aa = json_zip(json2)
    bb = json_unzip(aa)
    
